microstructpy.seeding
=====================

.. automodule:: microstructpy.seeding

The seeding module contains two classes: :class:`.Seed` and :class:`.SeedList`.
The single :class:`.Seed` contains the geometry, phase number, and position
of a seed, while a :class:`.SeedList` functions much like a list of
:class:`.Seed` instances, but with more methods.


.. only:: html

    **Module Contents**

.. toctree::

    seed
    seedlist